==> haskell-aeson-qq-0.8.4-297-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-qq
version:              0.8.4
visibility:           public
id:                   aeson-qq-0.8.4-H64Z59xncyf3t36RDWryn6
key:                  aeson-qq-0.8.4-H64Z59xncyf3t36RDWryn6
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Oscar Finnsson
homepage:             https://github.com/sol/aeson-qq#readme
synopsis:             JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.

    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature

    >aesonQQ :: QuasiQuoter

    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>

category:             JSON
abi:                  65d69b39d540f95f253c69e459aef021
exposed:              True
exposed-modules:      Data.Aeson.QQ
hidden-modules:       Data.JSON.QQ Paths_aeson_qq
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-qq-0.8.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-qq-0.8.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-qq-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-qq
hs-libraries:         HSaeson-qq-0.8.4-H64Z59xncyf3t36RDWryn6
depends:
    aeson-2.1.2.1-6ANjbGmrSDg8K6hz3VmYXP
    attoparsec-0.14.4-G1kY79wp4BCwb0EQHIFQA base-4.17.2.1
    base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    haskell-src-meta-0.8.15-64HnyFWFBJL1oUzcMt0a7M parsec-3.1.16.1
    scientific-0.3.8.0-eAJHzbOczMAHNfebkRy2Z template-haskell-2.19.0.0
    text-2.0.2 vector-0.13.2.0-ESntcdl2teUG0zU6GNugJH

haddock-interfaces:   /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html:         /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-qq-0.8.4-298-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-qq
version:              0.8.4
visibility:           public
id:                   aeson-qq-0.8.4-D98lg21TYycFuYcq9elOq
key:                  aeson-qq-0.8.4-D98lg21TYycFuYcq9elOq
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Oscar Finnsson
homepage:             https://github.com/sol/aeson-qq#readme
synopsis:             JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.

    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature

    >aesonQQ :: QuasiQuoter

    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>

category:             JSON
abi:                  0c3332588e6d989a2fffedcbdc60d65b
exposed:              True
exposed-modules:      Data.Aeson.QQ
hidden-modules:       Data.JSON.QQ Paths_aeson_qq
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-qq-0.8.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-qq-0.8.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-qq-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-qq
hs-libraries:         HSaeson-qq-0.8.4-D98lg21TYycFuYcq9elOq
depends:
    aeson-2.1.2.1-JflO2jKMgLf4qHLretO6v3
    attoparsec-0.14.4-2LtDsLmLe3yKhxR8c5Iii0 base-4.17.2.1
    base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    haskell-src-meta-0.8.15-6HTqACyM7vl5GFWmP0R81A parsec-3.1.16.1
    scientific-0.3.8.0-8fLTd8S79uT7C3Z3GpM5Vd template-haskell-2.19.0.0
    text-2.0.2 vector-0.13.2.0-ByKMfTK8tTR39fPNQcIOcc

haddock-interfaces:   /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html:         /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
